package main

import (
	"embed"
	"log"
	"net/http"

	"gitea.hackmi.ch/Phil/gobin/routes"
	"gitea.hackmi.ch/Phil/gobin/utils"
	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/template/html/v2"
)

//go:embed views/*
var viewsfs embed.FS

//go:embed assets/*
var publicfs embed.FS

func main() {

	utils.Init_ENV()

	engine := html.NewFileSystem(http.FS(viewsfs), ".html")

	app := fiber.New(fiber.Config{
		Views:        engine,
		ServerHeader: "gobin",
	})

	utils.ActivateAssets(app, &publicfs)
	utils.ActivateLogger(app)

	app.Get("/", routes.GetHome)

	app.Get("/tos", routes.GetTos)
	app.Get("/privacy", routes.GetPrivacy)
	app.Get("/imprint", routes.GetImprint)

	log.Fatal(app.Listen(":3000"))
}
